@@ -50,3 +50,5 @@ from .oms_service_medical import OmsServiceMedical
 from .oms_smo import OmsSmo
 from .oms_type_doc import OmsTypedoc
 from .x_user import XUser
+from .x_doc_type_def import XDocTypeDef
+from .x_doc_elem_def import XDocElemDef
